import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Pagination from '../Pagination';
import SelectPicker from '../SelectPicker';
import Divider from '../Divider';
import { tplTransform, useClassNames, useCustom } from '../utils';
var defaultProps = {
  as: 'div',
  classPrefix: 'table-pagination',
  showLengthMenu: true,
  showInfo: true,
  lengthMenu: [{
    value: 30,
    label: 30
  }, {
    value: 50,
    label: 50
  }, {
    value: 100,
    label: 100
  }],
  displayLength: 30,
  prev: true,
  next: true,
  first: true,
  last: true,
  activePage: 1,
  maxButtons: 5
};
var TablePagination = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var Component = props.as,
      classPrefix = props.classPrefix,
      total = props.total,
      prev = props.prev,
      next = props.next,
      first = props.first,
      last = props.last,
      maxButtons = props.maxButtons,
      className = props.className,
      displayLength = props.displayLength,
      activePage = props.activePage,
      disabled = props.disabled,
      style = props.style,
      reverse = props.reverse,
      lengthMenu = props.lengthMenu,
      showLengthMenu = props.showLengthMenu,
      localeProp = props.locale,
      showInfo = props.showInfo,
      renderTotal = props.renderTotal,
      renderLengthMenu = props.renderLengthMenu,
      onChangePage = props.onChangePage,
      onChangeLength = props.onChangeLength,
      rest = _objectWithoutPropertiesLoose(props, ["as", "classPrefix", "total", "prev", "next", "first", "last", "maxButtons", "className", "displayLength", "activePage", "disabled", "style", "reverse", "lengthMenu", "showLengthMenu", "locale", "showInfo", "renderTotal", "renderLengthMenu", "onChangePage", "onChangeLength"]);

  var _useClassNames = useClassNames(classPrefix),
      merge = _useClassNames.merge,
      prefix = _useClassNames.prefix;

  var _useCustom = useCustom('TablePagination', localeProp),
      locale = _useCustom.locale;

  var pages = Math.floor(total / displayLength) + (total % displayLength ? 1 : 0);
  var classes = merge(className, prefix('toolbar'));

  var renderMenu = function renderMenu() {
    if (!showLengthMenu) {
      return null;
    }

    var disabledPicker = typeof disabled === 'function' ? disabled('picker') : disabled;
    var picker = /*#__PURE__*/React.createElement(SelectPicker, {
      appearance: "subtle",
      cleanable: false,
      searchable: false,
      placement: "topStart",
      data: lengthMenu,
      value: displayLength,
      onChange: onChangeLength,
      menuStyle: {
        minWidth: 'auto'
      },
      disabled: disabledPicker
    });
    return /*#__PURE__*/React.createElement("div", {
      className: prefix('length-menu')
    }, renderLengthMenu ? renderLengthMenu(picker) : tplTransform(locale.lengthMenuInfo, picker));
  };

  var renderInfo = function renderInfo() {
    if (!showInfo) {
      return null;
    }

    return /*#__PURE__*/React.createElement("div", {
      className: prefix('page-info')
    }, renderTotal ? renderTotal(total, activePage) : tplTransform(locale.totalInfo, total));
  };

  var pagers = [/*#__PURE__*/React.createElement("div", {
    className: classNames(prefix('start')),
    key: 1
  }, renderMenu(), /*#__PURE__*/React.createElement(Divider, {
    vertical: true
  }), renderInfo()), /*#__PURE__*/React.createElement("div", {
    className: classNames(prefix('end')),
    key: 2
  }, /*#__PURE__*/React.createElement(Pagination, _extends({
    size: "xs",
    prev: prev,
    next: next,
    first: first,
    last: last,
    maxButtons: maxButtons,
    pages: pages,
    disabled: disabled,
    onSelect: onChangePage,
    activePage: activePage
  }, rest)))];
  return /*#__PURE__*/React.createElement(Component, {
    ref: ref,
    className: classes,
    style: style
  }, reverse ? pagers.reverse() : pagers);
});
TablePagination.displayName = 'TablePagination';
TablePagination.defaultProps = defaultProps;
TablePagination.propTypes = {
  lengthMenu: PropTypes.array,
  showLengthMenu: PropTypes.bool,
  showInfo: PropTypes.bool,
  total: PropTypes.number,
  displayLength: PropTypes.number,
  prev: PropTypes.bool,
  next: PropTypes.bool,
  first: PropTypes.bool,
  last: PropTypes.bool,
  maxButtons: PropTypes.number,
  activePage: PropTypes.number,
  className: PropTypes.string,
  locale: PropTypes.any,
  classPrefix: PropTypes.string,
  disabled: PropTypes.oneOfType([PropTypes.bool, PropTypes.func]),
  style: PropTypes.object,
  // reverse start and end position
  reverse: PropTypes.bool,
  renderLengthMenu: PropTypes.func,
  renderTotal: PropTypes.func,
  onChangePage: PropTypes.func,
  onChangeLength: PropTypes.func
};
export default TablePagination;