"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Pagination = _interopRequireDefault(require("../Pagination"));

var _SelectPicker = _interopRequireDefault(require("../SelectPicker"));

var _Divider = _interopRequireDefault(require("../Divider"));

var _utils = require("../utils");

var defaultProps = {
  as: 'div',
  classPrefix: 'table-pagination',
  showLengthMenu: true,
  showInfo: true,
  lengthMenu: [{
    value: 30,
    label: 30
  }, {
    value: 50,
    label: 50
  }, {
    value: 100,
    label: 100
  }],
  displayLength: 30,
  prev: true,
  next: true,
  first: true,
  last: true,
  activePage: 1,
  maxButtons: 5
};

var TablePagination = /*#__PURE__*/_react.default.forwardRef(function (props, ref) {
  var Component = props.as,
      classPrefix = props.classPrefix,
      total = props.total,
      prev = props.prev,
      next = props.next,
      first = props.first,
      last = props.last,
      maxButtons = props.maxButtons,
      className = props.className,
      displayLength = props.displayLength,
      activePage = props.activePage,
      disabled = props.disabled,
      style = props.style,
      reverse = props.reverse,
      lengthMenu = props.lengthMenu,
      showLengthMenu = props.showLengthMenu,
      localeProp = props.locale,
      showInfo = props.showInfo,
      renderTotal = props.renderTotal,
      renderLengthMenu = props.renderLengthMenu,
      onChangePage = props.onChangePage,
      onChangeLength = props.onChangeLength,
      rest = (0, _objectWithoutPropertiesLoose2.default)(props, ["as", "classPrefix", "total", "prev", "next", "first", "last", "maxButtons", "className", "displayLength", "activePage", "disabled", "style", "reverse", "lengthMenu", "showLengthMenu", "locale", "showInfo", "renderTotal", "renderLengthMenu", "onChangePage", "onChangeLength"]);

  var _useClassNames = (0, _utils.useClassNames)(classPrefix),
      merge = _useClassNames.merge,
      prefix = _useClassNames.prefix;

  var _useCustom = (0, _utils.useCustom)('TablePagination', localeProp),
      locale = _useCustom.locale;

  var pages = Math.floor(total / displayLength) + (total % displayLength ? 1 : 0);
  var classes = merge(className, prefix('toolbar'));

  var renderMenu = function renderMenu() {
    if (!showLengthMenu) {
      return null;
    }

    var disabledPicker = typeof disabled === 'function' ? disabled('picker') : disabled;

    var picker = /*#__PURE__*/_react.default.createElement(_SelectPicker.default, {
      appearance: "subtle",
      cleanable: false,
      searchable: false,
      placement: "topStart",
      data: lengthMenu,
      value: displayLength,
      onChange: onChangeLength,
      menuStyle: {
        minWidth: 'auto'
      },
      disabled: disabledPicker
    });

    return /*#__PURE__*/_react.default.createElement("div", {
      className: prefix('length-menu')
    }, renderLengthMenu ? renderLengthMenu(picker) : (0, _utils.tplTransform)(locale.lengthMenuInfo, picker));
  };

  var renderInfo = function renderInfo() {
    if (!showInfo) {
      return null;
    }

    return /*#__PURE__*/_react.default.createElement("div", {
      className: prefix('page-info')
    }, renderTotal ? renderTotal(total, activePage) : (0, _utils.tplTransform)(locale.totalInfo, total));
  };

  var pagers = [/*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)(prefix('start')),
    key: 1
  }, renderMenu(), /*#__PURE__*/_react.default.createElement(_Divider.default, {
    vertical: true
  }), renderInfo()), /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)(prefix('end')),
    key: 2
  }, /*#__PURE__*/_react.default.createElement(_Pagination.default, (0, _extends2.default)({
    size: "xs",
    prev: prev,
    next: next,
    first: first,
    last: last,
    maxButtons: maxButtons,
    pages: pages,
    disabled: disabled,
    onSelect: onChangePage,
    activePage: activePage
  }, rest)))];
  return /*#__PURE__*/_react.default.createElement(Component, {
    ref: ref,
    className: classes,
    style: style
  }, reverse ? pagers.reverse() : pagers);
});

TablePagination.displayName = 'TablePagination';
TablePagination.defaultProps = defaultProps;
TablePagination.propTypes = {
  lengthMenu: _propTypes.default.array,
  showLengthMenu: _propTypes.default.bool,
  showInfo: _propTypes.default.bool,
  total: _propTypes.default.number,
  displayLength: _propTypes.default.number,
  prev: _propTypes.default.bool,
  next: _propTypes.default.bool,
  first: _propTypes.default.bool,
  last: _propTypes.default.bool,
  maxButtons: _propTypes.default.number,
  activePage: _propTypes.default.number,
  className: _propTypes.default.string,
  locale: _propTypes.default.any,
  classPrefix: _propTypes.default.string,
  disabled: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.func]),
  style: _propTypes.default.object,
  // reverse start and end position
  reverse: _propTypes.default.bool,
  renderLengthMenu: _propTypes.default.func,
  renderTotal: _propTypes.default.func,
  onChangePage: _propTypes.default.func,
  onChangeLength: _propTypes.default.func
};
var _default = TablePagination;
exports.default = _default;
module.exports = exports.default;